/**
 * This enum represents the runtime environment items of interest.
 * These are more than just environment variables.
 * We will report on these items (and report on any detected problems)
 * in the order that the items are listed below.
 */
export declare enum ItemId {
    ZOWE_VER = 0,
    NODEJS_VER = 1,
    PLATFORM = 2,
    ARCHITECTURE = 3,
    OS_PATH = 4,
    ZOWE_CLI_HOME = 5,
    ZOWE_APP_LOG_LEVEL = 6,
    ZOWE_IMPERATIVE_LOG_LEVEL = 7,
    OTHER_ZOWE_VARS = 8,// Zowe variables not listed above
    NPM_VER = 9,
    ZOWE_CONFIG_INFO = 10,
    ZOWE_PLUGINS = 11
}
/**
 * This is the structure for defining a test to identify if a problem exists
 * for a given runtime environment item, and the message to give when the
 * problem is detected.
 */
export interface IProbTest {
    itemId: ItemId;
    probExpr: string;
    probMsg: string;
}
/**
 * The tests to check for problems that we run for environmental items.
 * One ItemId can have multiple entries in the array, to check for
 * different problems. When the probExpr is true, we have a problem,
 * and we print the probMsg.
 */
export declare const probTests: IProbTest[];
//# sourceMappingURL=EnvItems.d.ts.map