import { AbstractSession } from "@zowe/imperative";
import { ISearchOptions } from "./doc/ISearchOptions";
import { IZosFilesResponse } from "../../doc/IZosFilesResponse";
/**
 * This class holds helper functions that are used to list data sets and its members through the z/OS MF APIs
 */
export declare class Search {
    private static timerExpired;
    /**
     * Retrieve all data sets and members to search
     *
     * @param {AbstractSession}  session          - z/OS MF connection info
     * @param {ISearchOptions}   searchOptions    - contains the data set search options,
     *                                              including name, searchString, timeout, and maxConcurrentRequests
     *
     * @returns {Promise<IZosFilesResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} data set name must be set
     * @throws {Error} When the {@link ZosmfRestClient} throws an error
     */
    static dataSets(session: AbstractSession, searchOptions: ISearchOptions): Promise<IZosFilesResponse>;
    /**
     * Perform a prelimiary search on z/OSMF
     *
     * @param {AbstractSession}  session       - z/OS MF connection info
     * @param {ISearchOptions}   searchOptions - Search options
     * @param {ISearchItem[]}    searchItems   - List of items for searching
     *
     * @returns {Promise<string[]>} A list of members that contain the searched for term
     *
     * @throws {ImperativeError} when a download fails, or timeout is exceeded.
     */
    private static searchOnMainframe;
    /**
     * Perform a deep search locally
     *
     * @param {AbstractSession}  session       - z/OS MF connection info
     * @param {ISearchOptions}   searchOptions - Search options
     *
     * @returns {Promise<IZosFilesMatchResponse[]>} A list of members that contain the searched for term, and locations where the term appears
     *
     * @throws {ImperativeError} when a download fails, or timeout is exceeded.
     */
    private static searchLocal;
}
//# sourceMappingURL=Search.d.ts.map